==> nextcloud-20.0.13.tgz: nextcloud/apps/federation/l10n/sr.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Додат на листу сервера од поверења",
    "Server is already in the list of trusted servers." : "Сервер је већ на списку сервера од поверења.",
    "No server to federate with found" : "Није нађен сервер за здруживање",
    "Could not add server" : "Неуспело додавање сервера",
    "Federation" : "Здруживање",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Здруживање омогућава да се повежете са другим серверима од поверења и да размењујете корисничке директоријуме.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Здруживање омогућава да се повежете са другим серверима од поверења и да мењате корисничке директоријуме.",
    "Trusted servers" : "Сервери од поверења",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Здруживање омогућава да се повежете са другим серверима од поверења и да мењате корисничке директоријуме. На пример, федерација ће се користити за налажење спољних корисника код креирања здруженог дељења. Није потребно додати сервер као сервер од поверења да бисте направили здружено дељење.",
    "+ Add trusted server" : "+ Додај сервер од поверења",
    "Trusted server" : "Сервер од поверења",
    "Add" : "Додај"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-21.0.0p0.tgz: nextcloud/apps/federation/l10n/sr.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Додат на листу сервера од поверења",
    "Server is already in the list of trusted servers." : "Сервер је већ на списку сервера од поверења.",
    "No server to federate with found" : "Није нађен сервер за здруживање",
    "Could not add server" : "Неуспело додавање сервера",
    "Federation" : "Здруживање",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Здруживање омогућава да се повежете са другим серверима од поверења и да размењујете корисничке директоријуме.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Здруживање омогућава да се повежете са другим серверима од поверења и да мењате корисничке директоријуме.",
    "Trusted servers" : "Сервери од поверења",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Здруживање омогућава да се повежете са другим серверима од поверења и да мењате корисничке директоријуме. На пример, федерација ће се користити за налажење спољних корисника код креирања здруженог дељења. Није потребно додати сервер као сервер од поверења да бисте направили здружено дељење.",
    "Add server automatically once a federated share was created successfully" : "Додај сервер аутоматски по успешном прављењу здруженог дељења",
    "+ Add trusted server" : "+ Додај сервер од поверења",
    "Trusted server" : "Сервер од поверења",
    "Add" : "Додај"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
